@@ -1,19 +1,18 @@
 import csv
 import dataclasses
-import sys
 from collections import defaultdict
 from pathlib import Path
 from typing import Optional, List
 
 import typer
+from dumbo_utils.console import console
+from dumbo_utils.validation import validate
 from rich.progress import track
 from rich.table import Table
 
 from dumbo_esse3.esse3_wrapper import Esse3Wrapper
 from dumbo_esse3.primitives import StudentThesisState, ExamDescription, ExamNotes, ExamType, DateTime, Register, \
     RegisterActivity, ActivityType, NumberOfHours, ActivityTitle, StudentGraduation, Student, FinalScore, GraduationNote
-from dumbo_esse3.utils.console import console
-from dumbo_esse3.utils.validators import validate
 
 
 @dataclasses.dataclass(frozen=True)
@@ -131,7 +130,7 @@ def command_exams(
             if with_students and exam.number_of_students.positive:
                 console.print()
                 students = esse3_wrapper.fetch_students(course, exam.date_and_time)
-                console.print("\n".join(f"{student.id}\t{student.name}" for student in students))
+                console.print("\n".join(f"{student.name},{student.id}" for student in students))
                 console.print()
 
 
@@ -494,14 +493,22 @@ def command_upload_graduation_day(
             None,
             help="Date of the graduation day DD/MM/YYYY (today or from ESSE3 if omitted)"
         ),
-        no_committee: bool = typer.Option(False, "--no-committee", help="Don't change selected committee"),
+        exclude_from_committee: Optional[List[int]] = typer.Option(
+            None,
+            "--exclude-from-committee",
+            help="Index of the committee member to exclude (start with 1)"
+        ),
+        dry_run: bool = typer.Option(False, "--dry-run", help="Don't save data"),
 ) -> None:
     """
-    Upload scores for a graduation day.
+    Upload scores for a graduation day. Requires the role CHAIR OF COMMITTEE.
     The ID of the graduation day can be obtained with the command graduation-days.
     Scores are provided via a CSV file.
     """
     student_graduation_list = read_graduation_day_list(csv_file)
+    if exclude_from_committee:
+        for x in exclude_from_committee:
+            validate("committee index in 1..99", x, min_value=1, max_value=99)
 
     esse3_wrapper = new_esse3_wrapper()
     with console.status("Fetching graduation days..."):
@@ -513,6 +520,7 @@ def command_upload_graduation_day(
             graduation_day=days[of - 1],
             student_graduation_list=student_graduation_list,
             date=None if date is None else DateTime.parse_date(date),
-            no_committee=no_committee,
+            exclude_from_committee=exclude_from_committee,
+            dry_run=dry_run,
         )
     console.print("All done!")
