@@ -1,6 +1,7 @@
 import dataclasses
 from dataclasses import InitVar
 from typing import List, Final, Optional
+from lxml import html
 
 import typeguard
 from selenium import webdriver
@@ -11,8 +12,7 @@ from selenium.webdriver.common.by import By
 from dumbo_esse3.primitives import Course, Username, Password, Exam, Student, StudentThesisState, CdL, \
     ExamDescription, ExamNotes, ExamType, DateTime, Register, NumberOfHours, Semester, RegisterActivity, \
     ActivityTitle, ActivityType, GraduationDay, StudentGraduation
-from dumbo_esse3.utils import validators
-from dumbo_esse3.utils.validators import validate
+from dumbo_utils.validation import validate
 
 ESSE3_SERVER = "https://unical.esse3.cineca.it"
 URLs: Final = {
@@ -45,7 +45,7 @@ class Esse3Wrapper:
     __key = object()
 
     def __post_init__(self, key: object, username: Username, password: Password):
-        validators.validate('key', key, equals=self.__key, help_msg="Can only be instantiated using a factory method")
+        validate('key', key, equals=self.__key, help_msg="Can only be instantiated using a factory method")
         self.maximize()
         self.__login(username, password)
 
@@ -301,7 +301,8 @@ class Esse3Wrapper:
             graduation_day: GraduationDay,
             student_graduation_list: List[StudentGraduation],
             date: Optional[DateTime] = None,
-            no_committee: bool = False,
+            exclude_from_committee: Optional[List[int]] = None,
+            dry_run: bool = False,
     ) -> None:
         validate("at least one student", student_graduation_list, min_len=1, help_msg="No student was provided")
         self.driver.get(URLs["graduation_day_list"])
@@ -309,12 +310,14 @@ class Esse3Wrapper:
             By.XPATH,
             f"//table[@id = 'seduteAperte']/tbody/tr/td[text() = '{graduation_day}']/../td/a"
         ).send_keys(Keys.RETURN)
-        rows = self.driver.find_elements(By.XPATH, '//table[@id="elencoLaureandi"]/tbody/tr')
+
+        html_document = html.fromstring(self.driver.page_source)
+        rows = html_document.xpath('//table[@id="elencoLaureandi"]/tbody/tr')
         student_to_url = {
             Student.of(
-                student_id=row.find_element(By.XPATH, "td[2]").text,
-                student_name=row.find_element(By.XPATH, "td[1]").text,
-            ): row.find_element(By.XPATH, "td/a").get_attribute("href")
+                student_id=row.xpath("td[2]")[0].text,
+                student_name=row.xpath("td[1]")[0].text,
+            ): ESSE3_SERVER + '/' + row.xpath("td/a/@href")[0]
             for row in rows
         }
         student_to_graduation = {graduation.student: graduation for graduation in student_graduation_list}
@@ -325,18 +328,17 @@ class Esse3Wrapper:
         graduation_date = self.driver.find_element(By.ID, 'grad-dettLau-dataCt').text
         if not graduation_date:
             graduation_date = DateTime.now().stringify_date() if date is None else date.stringify_date()
-        if no_committee:
-            committee = []
-        else:
-            committee = [
-                checkbox.is_selected()
-                for checkbox in self.driver.find_elements(
-                    By.XPATH,
-                    '//table[starts-with(@id, "gradDettLauCommissione")]//input[@type = "checkbox"]'
-                )
-            ]
-            if all(not x for x in committee):
-                committee = [not x for x in committee]
+        committee = [
+            checkbox.is_selected()
+            for checkbox in self.driver.find_elements(
+                By.XPATH,
+                '//table[starts-with(@id, "gradDettLauCommissione")]//input[@type = "checkbox"]'
+            )
+        ]
+        if all(not x for x in committee):
+            committee = [not x for x in committee]
+        if exclude_from_committee:
+            committee = [x and index not in exclude_from_committee for index, x in enumerate(committee, start=1)]
 
         for graduation in student_graduation_list:
             url = student_to_url[graduation.student]
@@ -375,7 +377,8 @@ class Esse3Wrapper:
                     if member != checkboxes[index].is_selected():
                         checkboxes[index].send_keys(Keys.SPACE)
 
-            self.driver.find_element(By.ID, 'grad-dettLau-btnSubmit').send_keys(Keys.RETURN)
+            if not dry_run:
+                self.driver.find_element(By.ID, 'grad-dettLau-btnSubmit').send_keys(Keys.RETURN)
 
     @staticmethod
     def __replace_content(element, content):
